@@ -11,16 +11,16 @@ class State:
     The variables are immutable.
     """
     properties: dict
-    reference: NodeRef
+    node_ref: NodeRef
     is_reentry: bool = False
     parent_reference: Optional[NodeRef] = None
     header: dict = field(default_factory=lambda: {})
 
     def with_is_reentry(self, is_reentry: bool):
-        return State(self.properties, self.reference, is_reentry, self.parent_reference, self.header)
+        return State(self.properties, self.node_ref, is_reentry, self.parent_reference, self.header)
 
     def with_parent_reference(self, parent_reference: Optional[NodeRef]):
-        return State(self.properties, self.reference, self.is_reentry, parent_reference, self.header)
+        return State(self.properties, self.node_ref, self.is_reentry, parent_reference, self.header)
 
     def with_reference(self, reference: NodeRef):
         return State(self.properties, reference, self.is_reentry, self.parent_reference, self.header)
