@@ -46,7 +46,7 @@ class CacheableProcessStoreAdapter(ProcessStore):
         return self.delegate.read_process(ref)
 
     def write_state(self, state: State):
-        self.state_cache[str(state.reference)] = state
+        self.state_cache[str(state.node_ref)] = state
         self.delegate.write_state(state)
 
     def read_state(self, ref: NodeRef) -> State:
