@@ -25,7 +25,7 @@ class ManualTask(BpmnNode):
             return state, [CompleteAction(self.id)] + actions
 
         event = ManualEvent(environment.group, environment.process_id, self.id, {})
-        return state, [QueueAction(self.id, event=event)]
+        return state, [QueueAction(self.id, event=event, save_state=True)]
 
     def __repr__(self):
         return f"ManualTask({self.id})"
