@@ -8,9 +8,9 @@ from arrow_bpmn.__spi__.execution import State
 
 class ServiceTask(BpmnNode):
 
-    def __init__(self, element: dict):
-        super().__init__(element)
-        self.implementation = element["implementation"]
+    @property
+    def implementation(self):
+        return self.__dict__["implementation"]
 
     def execute(self, state: State, environment: Environment) -> Tuple[State, Actions]:
         delegate = environment.service_factory(environment.group, self.implementation)
