@@ -20,7 +20,6 @@ from arrow_bpmn.model.sequence.association import Association
 from arrow_bpmn.model.sequence.sequence_flow import SequenceFlow
 from arrow_bpmn.model.task.business_rule_task import BusinessRuleTask
 from arrow_bpmn.model.task.call_activity import CallActivity, VariableMapping, ExpressionMapping
-from arrow_bpmn.model.task.extension.http_task import HttpTask
 from arrow_bpmn.model.task.manual_task import ManualTask
 from arrow_bpmn.model.task.receive_task import ReceiveTask
 from arrow_bpmn.model.task.script_task import ScriptTask
@@ -82,21 +81,8 @@ class XmlBpmnParser(BpmnParser):
     def _parse_association(self, element: XMLElement):
         return Association(element.get_attributes())
 
-    # TODO: move code to ArrowBpmnParser
     def _parse_custom_task(self, task: XMLElement, events: EventDict):
-        _type = task.get_attribute("arrow:type")
-        assert _type is not None, "no task event specification found"
-
-        if _type == "http":
-            attributes = task.get_attributes()
-            if task.has_tag("bpmn:extensionElements"):
-                extension_elements = task.get_tag("bpmn:extensionElements")
-                headers = extension_elements.get_tags("arrow:httpHeader")
-                headers = {header.get_attribute("key"): header.get_attribute("value") for header in headers}
-                attributes["headers"] = headers
-            return HttpTask(attributes)
-
-        raise ValueError(f"cannot parse type {_type}")
+        raise ValueError(f"cannot parse custom task")
 
     def _parse_start_event(self, start_event: XMLElement, events: EventDict):
         event_definition = start_event.get_tag("bpmn:messageEventDefinition")
