@@ -31,16 +31,16 @@ class XMLElement:
     def get_attributes(self):
         return {x[0]: x[1] for x in self.element.items()}
 
-    def get_attribute(self, name: str, namespaces: Optional[dict] = None) -> Optional[str]:
+    def get_attribute(self, name: str, namespaces: Optional[dict] = None, default_value=None) -> Optional[str]:
         attributes = self.get_attributes()
 
         if ":" in name:
             array = name.split(":")
             namespace = (namespaces or NAMESPACES)[array[0]]
             key = "{" + namespace + "}" + array[1]
-            return attributes[key] if key in attributes else None
+            return attributes[key] if key in attributes else default_value
 
-        return attributes[name] if name in attributes else None
+        return attributes[name] if name in attributes else default_value
 
     def get_text(self, unescape: bool = False):
         if unescape:
